<img src="https://github.com/orchardbirds/bokbokbok/raw/main/docs/img/bokbokbok.png" width="120" align="right">

[![PyPi Version](https://img.shields.io/pypi/pyversions/bokbokbok)](#)
[![PyPI](https://img.shields.io/pypi/v/bokbokbok)](#)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/bokbokbok)](#)
![GitHub contributors](https://img.shields.io/github/contributors/orchardbirds/bokbokbok)


# bokbokbok

## Overview

**bokbokbok** is a python package that enables you to use Custom Loss Functions and Evaluation Metrics for XGBoost and LightGBM.
Main features:

- [Weighted Cross Entropy](https://orchardbirds.github.io/bokbokbok/tutorials/weighted_cross_entropy.html)
- [Weighted Focal Loss](https://orchardbirds.github.io/bokbokbok/tutorials/focal_loss.html)
- [Log Cosh Loss](https://orchardbirds.github.io/bokbokbok/tutorials/log_cosh_loss.html)
- [F1 score](https://orchardbirds.github.io/bokbokbok/tutorials/F1_score.html)

## Installation

```bash
pip install bokbokbok
```

## Documentation

The documentation can [be found here.](https://orchardbirds.github.io/bokbokbok/)

## Contributing

To learn more about making a contribution to bokbokbok, please see [CONTRIBUTING.md.](https://github.com/orchardbirds/bokbokbok/blob/main/CONTRIBUTING.md)